Welcome to django-tag-fields's documentation!
=============================================

This project is a hard clone of  `Jazzband django-taggit
<https://github.com/jazzband/django-taggit>`_.

``django-tag-fields`` is a reusable Django application designed to make adding
tagging to your project easy and fun.

``django-tag-fields V4.0.0`` continues to work as django-taggit==3.1.0.


``django-tag-fields`` works with Django 3.2+ and Python 3.6+.

.. toctree::
   :maxdepth: 2

   getting_started
   forms
   admin
   serializers
   api
   faq
   custom_tagging
   contributing
   external_apps
   changelog

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
